@@ -35,7 +35,7 @@ def get_current_session():
     return _CURRENT_SESSION
 
 
-def connection_required(func: Callable) -> Callable:
+"""def default_connection_required(func: Callable) -> Callable:
     def check_conn(*args, **kwargs):
         if len(get_current_session().servers) > 0:
             func(*args, **kwargs)
@@ -53,7 +53,7 @@ could not connect to default '{CURRENT_CONFIG.get('DEFAULT_SERVER')}"
             )
 
     return check_conn
-
+"""
 
 class AmqpSession:
     def __init__(self) -> None:
@@ -68,6 +68,23 @@ class AmqpSession:
     def pool(self) -> ConnectionPool:
         return self._connections
 
+    def connection_required(func: Callable) -> Callable:
+        def check_conn(self, *args, **kwargs):
+            if len(self.servers) > 0:
+                return func(self, *args, **kwargs)
+
+            try:
+                self.connect(CURRENT_CONFIG.get("DEFAULT_SERVER"))
+                return func(self, *args, **kwargs)
+            except (NotAuthenticatedError, ConnectionError, AttributeError) as e:
+                LOGGER.critical(f"Error when connecting to default server: {e}")
+                raise NotConnectedError(
+                    f"Need to be connected to a server,\
+    could not connect to default '{CURRENT_CONFIG.get('DEFAULT_SERVER')}"
+                )
+
+        return check_conn
+
     @connection_required
     def publish(
         self,
@@ -87,7 +104,7 @@ class AmqpSession:
     @connection_required
     def publish_all(
         self,
-        messages: Iterable[Union[str, Tuple[str, str]]],
+        messages: Iterable[Union[str, Tuple[str, Any]]],
         exchange: Optional[str] = None,
         block=False,
     ):
